@@ -1,5 +1,6 @@
 package Module::CPANTS::Generator::Files;
 use strict;
+use Clone qw(clone);
 use File::Spec::Functions;
 use Module::CPANTS::Generator;
 use base 'Module::CPANTS::Generator';
@@ -13,13 +14,18 @@ sub generate {
   my $cpants = $self->grab_cpants;
 
   foreach my $dist (sort grep { -d } <*>) {
+    if (exists $cpants->{$dist}->{files}) {
+      $cpants->{cpants}->{$dist}->{files} = clone($cpants->{$dist}->{files});
+      next;
+    }
+
     my @files;
     foreach my $file (qw(Makefile.PL README Build.PL META.yml SIGNATURE MANIFEST)) {
       if (-f catfile($dist, $file)) {
 	push @files, $file;
       }
       $cpants->{$dist}->{files} = \@files;
-
+      $cpants->{cpants}->{$dist}->{files} = clone($cpants->{$dist}->{files});
     }
   }
 
